#' This is an easy-to-use package for downloading, organizing, 
#' and integrative analyzing RNA expression data in GDC with an 
#' emphasis on deciphering the lncRNA-mRNA related ceRNA regulatory 
#' network in cancer.
#'
#' @name GDCRNATools-package
#' @aliases GDCRNATools-package GDCRNATools
#' @docType package
NULL



#' Output of \code{\link{gdcDEAnalysis}} for downstream analysis
#' @name DEGAll
#' @docType data
#' @keywords datasets
NULL


#' Output of \code{\link{gdcEnrichAnalysis}} for visualization
#' @name enrichOutput
#' @docType data
#' @keywords datasets
NULL


#' RNAseq counts data of TCGA-CHOL
#' @name rnaCounts
#' @docType data
#' @keywords datasets
NULL


#' miRNA counts data of TCGA-CHOL
#' @name mirCounts
#' @docType data
#' @keywords datasets
NULL


#' miRNA-lncRNA interactions
#' @name lncTarget
#' @docType data
#' @keywords datasets
NULL


#' miRNA-mRNA interactions
#' @name pcTarget
#' @docType data
#' @keywords datasets
NULL