% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GDCRNATools-package.R
\docType{data}
\name{mirCounts}
\alias{mirCounts}
\title{miRNA counts data of TCGA-CHOL}
\description{
miRNA counts data of TCGA-CHOL
}
\keyword{datasets}
