% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GDCRNATools-package.R
\docType{data}
\name{rnaCounts}
\alias{rnaCounts}
\title{RNAseq counts data of TCGA-CHOL}
\description{
RNAseq counts data of TCGA-CHOL
}
\keyword{datasets}
