% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GDCRNATools-package.R
\docType{data}
\name{pcTarget}
\alias{pcTarget}
\title{miRNA-mRNA interactions}
\description{
miRNA-mRNA interactions
}
\keyword{datasets}
