% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/GDCRNATools-package.R
\docType{data}
\name{lncTarget}
\alias{lncTarget}
\title{miRNA-lncRNA interactions}
\description{
miRNA-lncRNA interactions
}
\keyword{datasets}
